==> dqops-0.2.0.5-py2.py3-none-any.whl: dqops/client/models/comment_spec.py <==
import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="CommentSpec")


@attr.s(auto_attribs=True)
class CommentSpec:
    """
    Attributes:
        date (Union[Unset, datetime.datetime]): Comment date and time
        comment_by (Union[Unset, str]): Commented by
        comment (Union[Unset, str]): Comment text
    """

    date: Union[Unset, datetime.datetime] = UNSET
    comment_by: Union[Unset, str] = UNSET
    comment: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        date: Union[Unset, str] = UNSET
        if not isinstance(self.date, Unset):
            date = self.date.isoformat()

        comment_by = self.comment_by
        comment = self.comment

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if date is not UNSET:
            field_dict["date"] = date
        if comment_by is not UNSET:
            field_dict["comment_by"] = comment_by
        if comment is not UNSET:
            field_dict["comment"] = comment

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _date = d.pop("date", UNSET)
        date: Union[Unset, datetime.datetime]
        if isinstance(_date, Unset):
            date = UNSET
        else:
            date = isoparse(_date)

        comment_by = d.pop("comment_by", UNSET)

        comment = d.pop("comment", UNSET)

        comment_spec = cls(
            date=date,
            comment_by=comment_by,
            comment=comment,
        )

        comment_spec.additional_properties = d
        return comment_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> dqops-1.11.0-py2.py3-none-any.whl: dqops/client/models/comment_spec.py <==
import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="CommentSpec")


@_attrs_define
class CommentSpec:
    """
    Attributes:
        date (Union[Unset, datetime.datetime]): Comment date and time
        comment_by (Union[Unset, str]): Commented by
        comment (Union[Unset, str]): Comment text
    """

    date: Union[Unset, datetime.datetime] = UNSET
    comment_by: Union[Unset, str] = UNSET
    comment: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        date: Union[Unset, str] = UNSET
        if not isinstance(self.date, Unset):
            date = self.date.isoformat()

        comment_by = self.comment_by
        comment = self.comment

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if date is not UNSET:
            field_dict["date"] = date
        if comment_by is not UNSET:
            field_dict["comment_by"] = comment_by
        if comment is not UNSET:
            field_dict["comment"] = comment

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _date = d.pop("date", UNSET)
        date: Union[Unset, datetime.datetime]
        if isinstance(_date, Unset):
            date = UNSET
        else:
            date = isoparse(_date)

        comment_by = d.pop("comment_by", UNSET)

        comment = d.pop("comment", UNSET)

        comment_spec = cls(
            date=date,
            comment_by=comment_by,
            comment=comment,
        )

        comment_spec.additional_properties = d
        return comment_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
